@@ -1,9 +1,7 @@
 #!/bin/bash
 # packages = audit
 
-
-# Use auditctl, on RHEL7, default is to use augenrules
-sed -i "s%^ExecStartPost=.*%ExecStartPost=-/sbin/auditctl%" /usr/lib/systemd/system/auditd.service
+{{{ setup_auditctl_environment() }}}
 
 rm -f /etc/audit/rules.d/*
 
