@@ -1,8 +1,5 @@
 #!/bin/bash
 # packages = fapolicyd
-# remediation = none
-
-{{{ bash_shell_file_set("/etc/fapolicyd/fapolicyd.conf", "permissive", "1", "true") }}}
 
 if [ -f /etc/fapolicyd/compiled.rules ]; then
     active_rules_file="/etc/fapolicyd/compiled.rules"
@@ -11,8 +8,14 @@ else
 fi
 
 truncate -s 0 $active_rules_file
-
 echo "allow exe=/usr/bin/python3.7 : ftype=text/x-python" >> $active_rules_file
 echo "deny perm=any all : all" >> $active_rules_file
 
-{{{ bash_shell_file_set("/etc/fapolicyd/fapolicyd.conf", "permissive", "0", "true") }}}
+{{{ set_config_file(path="/etc/fapolicyd/fapolicyd.conf",
+                    parameter="permissive",
+                    value="0",
+                    create=true,
+                    insensitive=true,
+                    separator=" = ",
+                    separator_regex="\s*=\s*",
+                    prefix_regex="^\s*") }}}
