@@ -3,7 +3,7 @@
 # platform = Oracle Linux 8,Red Hat Enterprise Linux 8,Red Hat Enterprise Linux 9,multi_platform_fedora
 # variables = var_password_pam_unix_remember=5
 
-if authselect list-features minimal | grep -q with-pwhistory; then
+if authselect list-features sssd | grep -q with-pwhistory; then
     authselect select sssd --force
     authselect disable-feature with-pwhistory
 else
