@@ -9,7 +9,7 @@ sed -i "/.*TMOUT.*/d" /etc/profile
 test -f $TEST_FILE || touch $TEST_FILE
 
 if grep -q "TMOUT" $TEST_FILE; then
-	sed -i "s/.*TMOUT.*/declare -xr TMOUT=800/" $TEST_FILE
+	sed -i "s/.*TMOUT.*/typeset -xr TMOUT=800/" $TEST_FILE
 else
-	echo "declare -xr TMOUT=800" >> $TEST_FILE
+	echo "typeset -xr TMOUT=800" >> $TEST_FILE
 fi
