@@ -8,4 +8,6 @@
 
 {{{ bash_ini_file_set("/etc/NetworkManager/NetworkManager.conf", "main", "dns", "$var_networkmanager_dns_mode") }}}
 
-systemctl reload NetworkManager
+if {{{ bash_not_bootc_build() }}} ; then
+    systemctl reload NetworkManager
+fi
