@@ -4,6 +4,6 @@ useradd user_test
 
 TESTDIR="/usr/lib/dir/"
 
-mkdir $TESTDIR
-touch $TESTDIR/test_me
-chown user_test $TESTDIR/test_me
+mkdir -p "${TESTDIR}"
+touch "${TESTDIR}"/test_me
+chown user_test "${TESTDIR}"/test_me
