@@ -7,3 +7,7 @@
 clean_dconf_settings
 add_dconf_profiles
 add_dconf_setting "org/gnome/desktop/session" "idle-delay" "uint32 2900" "local.d" "00-security-settings"
+
+{{% if 'ubuntu' in product %}}
+add_dconf_lock "org/gnome/desktop/screensaver" "idle-delay" "local.d" "00-security-settings"
+{{% endif %}}
