@@ -1,8 +1,10 @@
 #!/bin/bash
 
-# platform = multi_platform_ubuntu
+# platform = multi_platform_all
 # packages = grub2
 
+source common.sh
+
 {{%- if ARG_VARIABLE %}}
 # variables = {{{ ARG_VARIABLE }}}=correct_value
 {{%- set ARG_NAME_VALUE= ARG_NAME ~ "=correct_value" %}}
