@@ -4,11 +4,13 @@
 {{% endif %}}
 
 # Clean sysctl config directories
+{{% if product not in ["sle12", "sle15", "slmicro5"] %}}
 rm -rf /usr/lib/sysctl.d/* /run/sysctl.d/* /etc/sysctl.d/*
 
 sed -i "/{{{ SYSCTLVAR }}}/d" /etc/sysctl.conf
-mkdir /usr/local/lib/sysctl.d/
+mkdir -p /usr/local/lib/sysctl.d
 echo "{{{ SYSCTLVAR }}} = {{{ SYSCTL_WRONG_VALUE }}}" >> /usr/local/lib/sysctl.d/wrong.conf
 
 # Setting correct runtime value
 sysctl -w {{{ SYSCTLVAR }}}="{{{ SYSCTL_CORRECT_VALUE }}}"
+{{% endif %}}
