@@ -24,8 +24,6 @@ def load_object(oval_object_xml_el):
 
 
 class ObjectOVAL(OVALEntity):
-    def __init__(self, tag, id_, properties):
-        super(ObjectOVAL, self).__init__(tag, id_, properties)
 
     def get_xml_element(self):
         return super(ObjectOVAL, self).get_xml_element()
