@@ -1,16 +1,17 @@
 from __future__ import print_function
 
 import contextlib
-import sys
-import os
-import re
-import time
-import subprocess
 import json
 import logging
+import os
+import re
+import subprocess
+import sys
+import time
 
 import ssg_test_suite
 from ssg_test_suite import common
+from ssg_test_suite.log import LogHelper
 
 
 class SavedState(object):
@@ -62,6 +63,7 @@ class TestEnv(object):
         self.running_state = None
 
         self.scanning_mode = scanning_mode
+        self.sce_support = False
         self.backend = None
         self.ssh_port = None
 
@@ -101,6 +103,7 @@ class TestEnv(object):
         by subsequent procedures.
         """
         self.refresh_connection_parameters()
+        self.check_sce_support()
 
     def refresh_connection_parameters(self):
         self.domain_ip = self.get_ip_address()
@@ -127,8 +130,9 @@ class TestEnv(object):
         if not error_msg_template:
             error_msg_template = "Return code of '{command}' on {remote_dest} is {rc}: {stderr}"
         remote_dest = "root@{ip}".format(ip=self.domain_ip)
-        result = common.run_with_stdout_logging(
+        result = common.retry_with_stdout_logging(
             "ssh", tuple(self.ssh_additional_options) + (remote_dest, command), log_file)
+        log_file.flush()
         if result.returncode:
             error_msg = error_msg_template.format(
                 command=command, remote_dest=remote_dest,
@@ -198,6 +202,16 @@ class TestEnv(object):
     def offline_scan(self, args, verbose_path):
         raise NotImplementedError()
 
+    def check_sce_support(self):
+        log_file_name = os.path.join(LogHelper.LOG_DIR, "env-preparation.log")
+        with open(log_file_name, 'a') as log_file:
+            oscap_output = self.execute_ssh_command("oscap --version", log_file)
+            sce_regex = r"SCE Version: [\d.]+ \(from libopenscap_sce.so.\d+\)"
+            for line in oscap_output.splitlines():
+                if re.match(sce_regex, line):
+                    self.sce_support = True
+                    return
+
 
 class VMTestEnv(TestEnv):
     name = "libvirt-based"
@@ -241,6 +255,9 @@ class VMTestEnv(TestEnv):
         self.domain = virt.connect_domain(
             self.hypervisor, self.domain_name)
 
+        if self.domain is None:
+            sys.exit(1)
+
         if not self.keep_snapshots:
             self.snapshots_cleanup()
 
@@ -516,6 +533,7 @@ class PodmanTestEnv(ContainerTestEnv):
         podman_cmd = ["podman", "run", "--name", long_name,
                       "--cap-add=cap_audit_write",
                       "--cap-add=cap_sys_admin",
+                      "--cap-add=cap_sys_chroot",
                     #   "--privileged",
                       "--publish", "{}".format(self.internal_ssh_port), "--detach", image_name,
                       "/usr/sbin/sshd", "-p", "{}".format(self.internal_ssh_port), "-D"]
