@@ -12,6 +12,7 @@ import xml.etree.ElementTree as ET
 import yaml
 
 import ssg.build_yaml
+import ssg.controls
 import ssg.environment
 import ssg.rules
 from ssg.utils import mkdir_p
@@ -44,6 +45,8 @@ def parse_args() -> argparse.Namespace:
                         help="What product to get STIGs for")
     parser.add_argument("-m", "--manual", type=str, action="store", required=True,
                         help="Path to XML XCCDF manual file to use as the source of the STIGs")
+    parser.add_argument("-g", "--srg-control", type=str, action="store", default=None,
+                        help="Path to the SRG control file relevant to the STIG")
     parser.add_argument("-j", "--json", type=str, action="store", default=RULES_JSON,
                         help=f"Path to the rules_dir.json (defaults to {RULES_JSON})")
     parser.add_argument("-c", "--build-config-yaml", default=BUILD_CONFIG,
@@ -80,12 +83,16 @@ def get_platform_rules(args):
     return platform_rules
 
 
-def get_implemented_stigs(args):
-    platform_rules = get_platform_rules(args)
+def map_rule_id_to_ref(rule_id, refs, known_rules):
+    for ref in refs:
+        if ref in known_rules:
+            known_rules[ref].append(rule_id)
+        else:
+            known_rules[ref] = [rule_id]
 
-    product_dir = os.path.join(args.root, "products", args.product)
-    product_yaml_path = os.path.join(product_dir, "product.yml")
-    env_yaml = ssg.environment.open_environment(args.build_config_yaml, str(product_yaml_path))
+
+def get_implemented_stigs(args, env_yaml):
+    platform_rules = get_platform_rules(args)
 
     known_rules = dict()
     for rule in platform_rules:
@@ -97,17 +104,8 @@ def get_implemented_stigs(args):
             # Happens on non-debug build when a rule is "documentation-incomplete"
             continue
 
-        if args.reference in rule_obj['references'].keys():
-            refs = rule_obj['references'][args.reference]
-            if ',' in refs:
-                refs = refs.split(',')
-            else:
-                refs = [refs]
-            for ref in refs:
-                if ref in known_rules:
-                    known_rules[ref].append(rule['id'])
-                else:
-                    known_rules[ref] = [rule['id']]
+        refs = rule_obj['references'].get(args.reference, [])
+        map_rule_id_to_ref(rule['id'], refs, known_rules)
     return known_rules
 
 
@@ -123,41 +121,88 @@ def check_files(args):
         exit(-1)
 
 
-def get_controls(known_rules, ns, root) -> list:
+def get_extra_srgs(rule, ns) -> list:
+    pattern = re.compile(r'SRG-[A-Z]{2,}-\d{5,}-[A-Z]{3,}-\d{5,}')
+
+    description = rule.find('checklist:description', ns).text
+    return pattern.findall(description)
+
+
+def get_rules_for_control(stig_id, known_rules, srgs, srg_controls):
+    # Add any known rule with the same STIG ID reference
+    rule_set = set()
+    if stig_id in known_rules.keys():
+        rule_set.update(known_rules.get(stig_id))
+
+    # Let's also add any rule selected in the SRG control file
+    if srg_controls:
+        for srg in srgs:
+            rule_set.update(srg_controls.get_control(srg).rules)
+
+    return sorted(list(rule_set))
+
+
+def get_controls(known_rules, ns, root, srg_controls=None) -> list:
     controls = list()
     for group in root.findall('checklist:Group', ns):
+        # There is always at least one SRG associated
+        srgs = [group.find('checklist:title', ns).text]
+
         for stig in group.findall('checklist:Rule', ns):
             stig_id = stig.find('checklist:version', ns).text
+            # Add any other SRG associated mentioned in description
+            srgs += get_extra_srgs(stig, ns)
             control = dict()
             control['id'] = stig_id
             control['levels'] = [stig.attrib['severity']]
             control['title'] = stig.find('checklist:title', ns).text
-            if stig_id in known_rules.keys():
-                control['rules'] = known_rules.get(stig_id)
+            control['rules'] = get_rules_for_control(stig_id, known_rules, srgs, srg_controls)
+            if len(control['rules']) > 0:
                 control['status'] = 'automated'
             else:
                 control['status'] = 'pending'
+
             controls.append(control)
     return controls
 
 
+def get_disa_stig_version(root, ns):
+    version = root.find('checklist:version', ns).text
+    release_string = root.find('checklist:plain-text[@id="release-info"]', ns).text
+    release = re.match(r'Release: (\d+) Benchmark', release_string)
+    return f"V{version}R{release.group(1)}"
+
+
 def main():
     args = parse_args()
     check_files(args)
 
+    product_dir = os.path.join(args.root, "products", args.product)
+    product_yaml_path = os.path.join(product_dir, "product.yml")
+    env_yaml = ssg.environment.open_environment(
+        args.build_config_yaml, product_yaml_path, os.path.join(args.root, "product_properties"))
+
     ns = {'checklist': 'http://checklists.nist.gov/xccdf/1.1'}
-    known_rules = get_implemented_stigs(args)
+    known_rules = get_implemented_stigs(args, env_yaml)
     tree = ET.parse(args.manual)
     root = tree.getroot()
     output = dict()
     output['policy'] = root.find('checklist:title', ns).text
     output['title'] = root.find('checklist:title', ns).text
     output['id'] = 'stig_%s' % args.product
+    output['version'] = get_disa_stig_version(root, ns)
     output['source'] = 'https://public.cyber.mil/stigs/downloads/'
+    output['reference_type'] = "stigid"
+    output['product'] = args.product
     output['levels'] = list()
     for level in ['high', 'medium', 'low']:
         output['levels'].append({'id': level})
-    controls = get_controls(known_rules, ns, root)
+
+    srg_controls = None
+    if args.srg_control:
+        srg_controls = ssg.controls.Policy(args.srg_control, env_yaml)
+        srg_controls.load()
+    controls = get_controls(known_rules, ns, root, srg_controls)
 
     if args.split:
         with open(args.output, 'w') as f:
