@@ -2,6 +2,7 @@
 
 import argparse
 import datetime
+import time
 import json
 import os
 import re
@@ -102,6 +103,20 @@ get_platform_rules.__annotations__ = {'product': str, 'json_path': str, 'resolve
                                       'build_root': str, 'return': list}
 
 
+def _open_rule_obj(resolved_rules_dir, rule, product, env_yaml):
+    if resolved_rules_dir:
+        return rule
+    try:
+        rule_obj = handle_rule_yaml(
+            product, rule['id'], rule['dir'], rule['guide'], env_yaml)
+    except ssg.yaml.DocumentationNotComplete:
+        msg = 'Rule %s throw DocumentationNotComplete' % rule['id']
+        sys.stderr.write(msg)
+        # Happens on non-debug build when a rule is "documentation-incomplete"
+        return None
+    return rule_obj
+
+
 def get_implemented_stigs(product, root_path, build_config_yaml_path,
                           reference_str, json_path, resolved_rules_dir,
                           build_root):
@@ -114,19 +129,13 @@ def get_implemented_stigs(product, root_path, build_config_yaml_path,
 
     known_rules = dict()
     for rule in platform_rules:
-        if resolved_rules_dir:
-            rule_obj = rule
-        else:
-            try:
-                rule_obj = handle_rule_yaml(product, rule['id'],
-                                            rule['dir'], rule['guide'], env_yaml)
-            except ssg.yaml.DocumentationNotComplete:
-                sys.stderr.write('Rule %s throw DocumentationNotComplete' % rule['id'])
-                # Happens on non-debug build when a rule is "documentation-incomplete"
-                continue
-
-        if reference_str in rule_obj['references'].keys():
-            ref = rule_obj['references'][reference_str]
+        rule_obj = _open_rule_obj(resolved_rules_dir, rule, product, env_yaml)
+        if not rule_obj:
+            continue
+        if reference_str not in rule_obj['references'].keys():
+            continue
+        refs = rule_obj['references'][reference_str]
+        for ref in refs:
             if ref in known_rules:
                 known_rules[ref].append(rule['id'])
             else:
@@ -157,10 +166,8 @@ setup_tailoring_profile.__annotations__ = {'profile_id': str, 'profile_root': ET
 
 
 def _get_datetime():
-    try:
-        return datetime.datetime.now(datetime.UTC).isoformat()
-    except AttributeError:
-        return datetime.datetime.utcnow().isoformat()
+    return datetime.datetime.fromtimestamp(
+        int(os.environ.get('SOURCE_DATE_EPOCH', time.time()))).isoformat()
 
 
 def create_tailoring(args):
@@ -169,14 +176,15 @@ def create_tailoring(args):
                                         args.reference, args.json, args.resolved_rules_dir,
                                         args.build_root)
     needed_rules = filter_out_implemented_rules(known_rules, NS, benchmark_root)
+    needed_rule_names_set = set(rulename for ruleset in needed_rules.values() for rulename in ruleset)
     profile_root = get_profile(args.product, args.profile)
     selections = profile_root.findall('xccdf-1.2:select', NS)
     tailoring_profile = setup_tailoring_profile(args.profile_id, profile_root)
     for selection in selections:
         if selection.attrib['idref'].startswith(ssg.constants.OSCAP_RULE):
             cac_rule_id = selection.attrib['idref'].replace(ssg.constants.OSCAP_RULE, '')
-            desired_value = str([cac_rule_id] in list(needed_rules.values())).lower()
-            if not bool(selection.get('selected')) == desired_value:
+            desired_value = str(cac_rule_id in needed_rule_names_set).lower()
+            if selection.get('selected') != desired_value:
                 selection.set('selected', desired_value)
                 tailoring_profile.append(selection)
                 if not args.quiet:
